======
 Tags
======

Tag application processes
=========================

Unless a specific tag, or group of tags, states otherwise, the criteria
required for each tag is objective and anyone may propose adding or removing
tags to a set of projects by proposing a change to the ``openstack/governance``
repository. The change is reviewed by the Technical Committee and approved
using standard resolution approval rules, including discussion during at least
one Technical Committee public IRC meeting.

The Technical Committee may approve any future updates to tag definitions and
otherwise defer applications of tags.

TC Managed Tags
===============

.. toctree::
   :maxdepth: 1
   :glob:

   starter-kit_compute
   starter-kit_kubernetes-in-virt


Team Description Tags
=====================

.. toctree::
   :maxdepth: 1

   status_maintenance-mode

Project Assertion Tags
======================

Project assertion tags are set by the project team PTL or suitable designee
based on meeting the documented criteria.

The project asserting these tags should do so when the documented requirements
are met for the reference implementation(s) or configuration(s) officially
adopted by that project.

The Technical Committee may exceptionally remove tags if they find that the
project doesn't actually meet the documented criteria.

.. toctree::
   :maxdepth: 1

   assert_follows-standard-deprecation
   assert_supports-api-interoperability
   assert_supports-upgrade
   assert_supports-accessible-upgrade
   assert_supports-rolling-upgrade
   assert_supports-standalone

Vulnerability Management Tags
=============================

.. toctree::
   :maxdepth: 1

   vulnerability_managed

Stable Maintenance Tags
=======================

.. toctree::
   :maxdepth: 1

   stable_follows-policy
